<script setup lang="ts">

import {ScreenApi, ScreenQueueVO} from "@/api/ecg/screen";
import {CallApi, CallVO} from "@/api/ecg/call";
import {queueStatusConvert} from "@/utils/statusFormatter";

defineOptions({ name: 'bigscreen' })

const displayColInfo = ref({})

const list = ref({});
// const listReady = ref<ScreenQueueVO[]>([]) // 列表的数据
// const listWaiting = ref<ScreenQueueVO[]>([]) // 列表的数据
// const listPassed = ref<ScreenQueueVO[]>([]) //

let curSpeakPat : CallVO | null = null;

const getDisplayColInfo = async () => {
  const data = await ScreenApi.getDisplayColInfo()
  displayColInfo.value = data
}

const getList = async () => {
  const data = await ScreenApi.getBigScreenData()
  console.info(data)
  list.value = data;
  // listReady.value = data[1]
  // listWaiting.value = data[2]
  // listPassed.value = data[3]
}

const startScrolling = () => {
  setInterval(() => {
    getList();
    if ( curSpeakPat === null ) {
      initiateSpeak()
    }
  }, 5000); // 每X秒滚动一次
}

onMounted( () => {
  getDisplayColInfo()
  startScrolling()
})

const onSpeachEndEvent = async (event) => {
  console.log("Speech ended... " + event.currentTarget.text);
  curSpeakPat!.called = 1
  await CallApi.updateCall(curSpeakPat!)
  initiateSpeak()
}

const initiateSpeak = async () => {
  curSpeakPat = await CallApi.getNextCall()
  console.info( curSpeakPat )
  if (curSpeakPat !== null) {
    speak("请、" + curSpeakPat.patName + "到" + curSpeakPat.roomName + "就诊");
  }
}

const speak = (msg) => {
  console.info("speak " + msg);
  var speech = new SpeechSynthesisUtterance()
  speech.text = msg + "。。。" + msg + "。。。" + msg  + "。。。"
  speech.pitch = 1 // 获取并设置话语的音调(0-2 默认1，值越大越尖锐,越低越低沉)
  speech.rate = 0.9 // 获取并设置说话的速度(0.1-10 默认1，值越大语速越快,越小语速越慢)
  speech.volume = 100 // 获取并设置说话的音量
  speech.lang = 'zh-CN' // 设置播放语言

  speech.onend = onSpeachEndEvent
  speechSynthesis.speak(speech)
}

const nameDesensitize = (patName) => {
  if (patName.length == 2) {
    //截取name 字符串截取第一个字符，
    return patName.substring(0, 1) + '*';
  } else if (patName.length == 3) {
    //截取第一个和第三个字符
    return patName.substring(0, 1) + '*' + patName.substring(2, 3);
  } else if (patName.length > 3) {
    //截取第一个和大于第4个字符
    return (
        patName.substring(0, 1) + '*' + '*' + patName.substring(3, patName.length)
    );
  }
}

// const listReady = ref<ScreenQueueVO[]>([]) // 列表的数据
// const listWaiting = ref<ScreenQueueVO[]>([]) // 列表的数据
// const listPassed = ref<ScreenQueueVO[]>([]) //

const getListReady = (col: number) : ScreenQueueVO[] => {
  console.info(list[col*1000])
  return list[col*1000]
}
const getListWaiting = (col: number) : ScreenQueueVO[] => {
  return list[col*1000 + 1]
}
const getListPassed = (col: number) : ScreenQueueVO[] => {
  return list[col*1000 + 2]
}

</script>

<template>
  <div style="height: 100%; display:flex; flex-direction: column">
    <div style="display:flex; justify-content: center; align-items: center; background: var(--el-color-primary-light-7);">
      <img height="40px" src="@/assets/imgs/jinhua.png"/>
      金华人民医院
    </div>
    <div style="display:flex; justify-content:space-around; align-items: flex-start;">
      <div v-for="[disColId, disNames] of Object.entries(displayColInfo)" :key="disColId">
        {{disColId}} {{ disNames }}
      </div>
    </div>
    <div style="display:flex; justify-content:space-around; align-items: flex-start; flex-grow: 1">
      <div v-for="[disColId2, mapSlot] of Object.entries(list)" :key="disColId2">
        <div v-for="[slotId, slotQueue] of Object.entries(mapSlot)" :key="slotId">
          <div v-for="(item, index) in slotQueue" :key="index">
            {{item.seqNum}} &nbsp; {{ nameDesensitize(item.patName) }} {{queueStatusConvert(item.status)}} {{item.roomName}}
          </div>
        </div>
      </div>
    </div>
    <div style="display:flex; justify-content: center; align-items: center; background: var(--el-color-primary-light-7);">
      <el-button @click="speak('欢迎使用')" >欢迎使用</el-button>
    </div>
  </div>
</template>

<style scoped lang="scss">
.el-header {
  background-color: var(--el-color-primary-light-7);
  color: #333;
  text-align: center;
  line-height: 40px;

  display: flex;
  align-items: center;
  justify-content: center;
}

.el-footer {
  //background-color: var(--el-color-primary-light-7);
  color: #333;
  text-align: center;
  line-height: 60px;
}

.el-aside {
  background-color: var(--el-color-primary-light-7);
  color: #333;
  text-align: center;
  line-height: 200px;
}

.el-main {
  //background-color: var(--el-color-primary-light-7);
  color: #333;
  text-align: center;
  line-height: 160px;
}

body > .el-container {
  margin-bottom: 40px;
}

</style>
